This crate contains kube-rs compatible bindings for Kubernetes custom resources for the flink.apache.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
flink.apache.org/v1beta1
FlinkDeploymentFlinkSessionJob